@@ -1,4 +1,4 @@
-#include "parts/doctest_impl.h"
+#include "doctest.cpp"
 
 int main(int argc, char** argv) {
     doctest::Context context;
@@ -22,9 +22,5 @@ int main(int argc, char** argv) {
     int client_stuff_return_code = 0;
     // your program - if the testing framework is integrated in your production code
 
-#ifdef WITH_PAUSE
-    system("pause");
-#endif // WITH_PAUSE
-
     return res + client_stuff_return_code; // the result from doctest is propagated here as well
 }
